PaymentGatewaySettings class

Constructors

PaymentGatewaySettings({String? id, String? label, String? description, String? type, String? value, String? dDefault, String? tip, String? placeholder})
PaymentGatewaySettings.fromJson(String source)
factory
PaymentGatewaySettings.fromMap(Map<String, dynamic> map)
factory

Properties

dDefault → String?
final
description → String?
final
hashCode → int
The hash code for this object.
no setteroverride
id → String?
final
label → String?
final
placeholder → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tip → String?
final
type → String?
String Type of setting.
final
value → String?
final

Methods

copyWith({String? id, String? label, String? description, String? type, String? value, String? dDefault, String? tip, String? placeholder}) → PaymentGatewaySettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override