Post class

Constructors

Post({String? date, String? dateGmt, String? guid, int? id, String? link, String? modified, String? modifiedGmt, String? slug, String? status, String? type, String? password, String? permalinkTemplate, String? generatedSlug, String? title, String? content, int? author, String? excerpt, int? featuredMedia, String? commentStatus, String? pingStatus, String? format, dynamic meta, bool? sticky, String? template, List<int>? categories, List<int>? tags, EmbedModel? embedModel})
Post.fromJson(String source)
factory
Post.fromMap(Map<String, dynamic> map)
factory

Properties

author → int?
The ID for the author of the object.
final
categories → List<int>?
The terms assigned to the object in the category taxonomy.
final
commentStatus → String?
Whether or not comments are open on the object.
final
content → String?
The content for the object.
final
date → String?
The date the object was published, in the site's timezone.
final
dateGmt → String?
The date the object was published, as GMT.
final
embedModel → EmbedModel?
final
excerpt → String?
The excerpt for the object.
final
featuredMedia → int?
The ID of the featured media for the object.
final
format → String?
The format for the object.
final
generatedSlug → String?
Slug automatically generated from the object title.
final
guid → String?
The globally unique identifier for the object.
final
hashCode → int
The hash code for this object.
no setteroverride
id → int?
Unique identifier for the object.
final
URL to the object.
final
meta → dynamic
Meta fields.
final
modified → String?
The date the object was last modified, in the site's timezone
final
modifiedGmt → String?
The date the object was last modified, as GMT.
final
password → String?
A password to protect access to the content and excerpt.
final
permalinkTemplate → String?
Permalink template for the object.
final
pingStatus → String?
Whether or not the object can be pinged.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug → String?
An alphanumeric identifier for the object unique to its type.
final
status → String?
A named status for the object.
final
sticky → bool?
Whether or not the object should be treated as sticky.
final
tags → List<int>?
The terms assigned to the object in the post_tag taxonomy.
final
template → String?
The theme file to use to display the object.
final
title → String?
The title for the object.
final
type → String?
Type of Post for the object.
final

Methods

copyWith({String? date, String? dateGmt, String? guid, int? id, String? link, String? modified, String? modifiedGmt, String? slug, String? status, String? type, String? password, String? permalinkTemplate, String? generatedSlug, String? title, String? content, int? author, String? excerpt, int? featuredMedia, String? commentStatus, String? pingStatus, String? format, dynamic meta, bool? sticky, String? template, List<int>? categories, List<int>? tags, EmbedModel? embedModel}) → Post
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override